from setuptools import setup

setup(name='valery',
      version='0.0.1',
      description='Valery is a static site generator',
      url='https://gitlab.com/13g10n/valery',
      author='Ivan Borisenko',
      author_email='mteru00@gmail.com',
      license='MIT',
      packages=['valery'],
      zip_safe=False)
